Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/spreed.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/lib/Model
diff options
context:
space:
mode:
authorJoas Schilling <coding@schilljs.com>2021-09-23 17:16:02 +0300
committerJoas Schilling <coding@schilljs.com>2021-10-07 19:18:30 +0300
commit3b4f96031e45d9d7bc074715fad13621a72910ea (patch)
tree250b7434244eecf44e4204567d91f20e53e2ed9f /lib/Model
parentf18aa001c7349592c7354e397589ce556c1f5139 (diff)
Fix permission handling in unit tests
Signed-off-by: Joas Schilling <coding@schilljs.com>
Diffstat (limited to 'lib/Model')
-rw-r--r--lib/Model/Attendee.php12
1 files changed, 9 insertions, 3 deletions
diff --git a/lib/Model/Attendee.php b/lib/Model/Attendee.php
index 5bcee1029..3870098b5 100644
--- a/lib/Model/Attendee.php
+++ b/lib/Model/Attendee.php
@@ -76,9 +76,15 @@ class Attendee extends Entity {
public const PERMISSIONS_PUBLISH_AUDIO = 16;
public const PERMISSIONS_PUBLISH_VIDEO = 32;
public const PERMISSIONS_PUBLISH_SCREEN = 64;
- public const PERMISSIONS_MAX = 127; // Max int (when all permissions are granted)
-
- public const PUBLISHING_PERMISSIONS_ALL = 7;
+ public const PERMISSIONS_MAX_DEFAULT = // Max int (when all permissions are granted as default)
+ self::PERMISSIONS_CALL_START
+ | self::PERMISSIONS_CALL_JOIN
+ | self::PERMISSIONS_LOBBY_IGNORE
+ | self::PERMISSIONS_PUBLISH_AUDIO
+ | self::PERMISSIONS_PUBLISH_VIDEO
+ | self::PERMISSIONS_PUBLISH_SCREEN
+ ;
+ public const PERMISSIONS_MAX_CUSTOM = self::PERMISSIONS_MAX_DEFAULT | self::PERMISSIONS_CUSTOM; // Max int (when all permissions are granted as custom)
/** @var int */
protected $roomId;